/*-------------------------------------------------------------------------+
| Copyright 2012 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editor.annotations;

import static org.eclipse.wb.swt.ResourceManager.getPluginImage;
import static org.fortiss.tooling.base.ui.ToolingBaseUIActivator.PLUGIN_ID;

import org.eclipse.core.resources.IMarker;
import org.eclipse.jface.text.Position;
import org.eclipse.jface.text.source.Annotation;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.graphics.RGB;

/**
 * Objects of this class represent one error annotation.
 * 
 * @author doebber
 */
public class ErrorAnnotation extends Annotation {
	/** Stores the marker. */
	private IMarker marker;
	/** Stores the error text. */
	private String text;
	/** Stores the line number. */
	private int line;
	/** Stores the error's text position. */
	private Position position;
	/** Stores the error type. */
	public static String ERROR_TYPE = "error.type";
	/** Stores the error color. */
	public static final RGB ERROR_RGB = new RGB(255, 0, 0);

	/** Constructor. */
	public ErrorAnnotation(IMarker marker) {
		this.marker = marker;
	}

	/** Constructor. */
	public ErrorAnnotation(int line, String text) {
		super(ERROR_TYPE, true, null);
		this.marker = null;
		this.line = line;
		this.text = text;
	}

	/** Returns the marker. */
	public IMarker getMarker() {
		return marker;
	}

	/** Returns the line. */
	public int getLine() {
		return line;
	}

	/** Returns the error text. */
	@Override
	public String getText() {
		return text;
	}

	/** Returns the image. */
	public Image getImage() {
		return getPluginImage(PLUGIN_ID, "/icons/error.gif");
	}

	/** Returns the layer. */
	public int getLayer() {
		return 3;
	}

	/** Returns the type. */
	@Override
	public String getType() {
		return ERROR_TYPE;
	}

	/** Returns the position. */
	public Position getPosition() {
		return position;
	}

	/** Sets the position. */
	public void setPosition(Position position) {
		this.position = position;
	}
}
