/*-------------------------------------------------------------------------+
| Copyright 2019 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editor.fx.visuals;

import static javafx.scene.paint.Color.BLACK;
import static javafx.scene.paint.Color.rgb;
import static org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewerDefaultTags.LINK_TARGET_ALLOWED_TAG;
import static org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewerDefaultTags.LINK_TARGET_DENIED_TAG;
import static org.fortiss.tooling.base.ui.editor.fx.visuals.CoordinateCorrections.ANCHOR_DIMENSION;
import static org.fortiss.tooling.base.ui.editor.fx.visuals.CoordinateCorrections.ANCHOR_INSET;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.getNodePosition;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IDiagramAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual.elliptic.CircularDiagramAnchorageVisualBase;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.model.layout.Point;

import javafx.geometry.Dimension2D;
import javafx.geometry.Rectangle2D;
import javafx.scene.paint.Color;
import javafx.scene.paint.Paint;

/**
 * {@link CircularDiagramAnchorageVisualBase} providing a default visual for diagram ports in
 * standard boxes-and-wires diagrams based on {@link ILayoutedModelElement}s.
 * 
 * @author munaro
 */
public abstract class LayoutedCircularDiagramAnchorageVisualBase
		extends CircularDiagramAnchorageVisualBase {

	/** Constructor. */
	public LayoutedCircularDiagramAnchorageVisualBase(
			IDiagramAnchorageMVCBundle mvcb) {
		super(mvcb);
		// TODO(#3877): Move type checks to a common base class.
		Object model = mvcb.getModel();
		if(!(model instanceof ILayoutedModelElement)) {
			throw new IllegalArgumentException(
					"Expected model of type ILayoutedModelElement, but was " +
							model.getClass().getSimpleName());
		}
	}

	/** {@inheritDoc} */
	@Override
	public Rectangle2D getModelBounds() {
		Point p = getNodePosition(getLayoutedModelElement());
		Dimension2D dim = getDimensions();
		return new Rectangle2D(p.getX(), p.getY(), dim.getWidth(), dim.getHeight());
	}

	/** {@inheritDoc} */
	@Override
	public Dimension2D getDimensions() {
		return ANCHOR_DIMENSION;
	}

	/** {@inheritDoc} */
	@Override
	protected double getInset() {
		return ANCHOR_INSET;
	}

	/** {@inheritDoc} */
	@Override
	protected Paint getBorderColor() {
		return BLACK;
	}

	/** {@inheritDoc} */
	@Override
	protected double getOpacity() {
		return 1.0;
	}

	/** {@inheritDoc} */
	@Override
	protected double getBorderWidth() {
		return 1.0;
	}

	/** {@inheritDoc} */
	@Override
	protected Color getInteractionColor() {
		IDiagramAnchorageMVCBundle mvcBundle = getMVCBundle();
		if(mvcBundle.hasTag(LINK_TARGET_DENIED_TAG)) {
			return rgb(255, 0, 0, .25);
		}
		if(mvcBundle.hasTag(LINK_TARGET_ALLOWED_TAG)) {
			return rgb(0, 255, 0, .25);
		}
		return super.getInteractionColor();
	}

	/** Return the {@link ILayoutedModelElement}. */
	// TODO(#3877): Move type checks to a common base class.
	private ILayoutedModelElement getLayoutedModelElement() {
		// Safe wild cast due to type check in constructor
		return (ILayoutedModelElement)getModel();
	}
}
