/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.data;

import static org.fortiss.tooling.kernel.utils.EcoreUtils.copy;

import org.eclipse.emf.ecore.EObject;

/**
 * Prototypes consist of a generic description and pre-configured {@link EObject}.
 * 
 * @author hoelzl
 */
public class Prototype {

	/** The generic prototype name. */
	private final String name;

	/** The pre-configured {@link EObject}. */
	protected final EObject prototype;

	/** Flag for primary class prototypes. */
	private final boolean isPrimary;

	/** Constructor. */
	public Prototype(String name, EObject prototype, boolean isPrimary) {
		this.name = name;
		this.prototype = prototype;
		this.isPrimary = isPrimary;
	}

	/** Returns the {@link Prototype}'s name. */
	public String getName() {
		return name;
	}

	/** Returns the {@link Prototype} instance (NOT a copy!). */
	public EObject getPrototype() {
		return prototype;
	}

	/** Returns a copy of the {@link Prototype}. This method is potentially expensive. */
	public EObject getPrototypeCopy() {
		return copy(prototype);
	}

	/** {@inheritDoc} */
	@Override
	public String toString() {
		return "Prototype for: " + name;
	}

	/** Returns whether this {@link Prototype} is a primary one or not. */
	public boolean isPrimary() {
		return isPrimary;
	}
}
