/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.change.Change;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundle;

import javafx.scene.Node;

/** Interface for controllers, which handle standard drag gestures provided by the visuals. */
public interface IDragController {
	/**
	 * Informs the drag controller that the drag gesture has started on the given bundle, node and
	 * diagram location.
	 */
	void dragStarted(IMVCBundle startBundle, Node startNode, DiagramCoordinate lastMouseLocation);

	/** Updates the drag controller with the new drag bundle, node, and diagram location. */
	void dragInProgress(IMVCBundle currentBundle, Node currentNode,
			DiagramCoordinate lastMouseLocation);

	/**
	 * Informs the drag controller about the final result: the target bundle, target node and
	 * diagram location. This operation may result in a {@link Change} to the underlying model.
	 */
	Change dragCompleted(IMVCBundle endBundle, Node endNode, DiagramCoordinate lastMouseLocation);
}
