/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.model;

import java.util.List;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewer;

/** Factory class for providing model data to the {@link DiagramViewer}. */
public interface IModelFactory {
	/** The root model element, which is presented as the background of the diagram. */
	Object getRootModel();

	/**
	 * The content model elements, which are represented by their visuals. Usually, the parent model
	 * element of these is the root element.
	 */
	List<?> getContentModels();

	/**
	 * The anchorage model elements of the root element, which are presented as freely positioned
	 * visuals. The parent of these elements is usually the root element.
	 */
	List<?> getDiagramAnchorageModels();

	/**
	 * The anchorage model elements of the given content model elements, which are presented as
	 * visuals sticking to their content parent visual's border.
	 */
	List<?> getContentAnchorageModels(Object parent);

	/**
	 * The link model elements of the root element, which connect between interface model
	 * elements of both the root and/or content model elements.
	 */
	List<?> getLinkModels();

	/**
	 * Returns the model element, which is the start of the given link element. The returned
	 * element must be contained in either {@link #getDiagramAnchorageModels()} or
	 * {@link #getContentAnchorageModels(Object)}.
	 */
	Object getLinkStart(Object link);

	/**
	 * Returns the model element, which is the end of the given link element. The returned
	 * element must be contained in either {@link #getDiagramAnchorageModels()} or
	 * {@link #getContentAnchorageModels(Object)}.
	 */
	Object getLinkEnd(Object link);

	/**
	 * Returns the model element, which is considered the parent content model of the given model
	 * element.
	 */
	Object getParent(Object element);

	/** Update the model factory's auxiliary data before calling any of the other methods. */
	void update();
}
