/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.impl;

import static java.util.Objects.requireNonNull;

import java.util.LinkedList;
import java.util.List;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewer;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.ILinkMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundle;

/** Base class for {@link IAnchorageMVCBundle}s. */
abstract class AnchorageMVCBundleBase extends MVCBundleBase implements IAnchorageMVCBundle {
	/** The parent bundle this bundle is attached to. */
	private IMVCBundle attachedTo;
	/** The list of incoming links. */
	private final List<ILinkMVCBundle> incomingLinks = new LinkedList<>();
	/** The list of outgoing links. */
	private final List<ILinkMVCBundle> outgoingLinks = new LinkedList<>();

	/** Constructor. */
	public AnchorageMVCBundleBase(Object m, IMVCBundle attachedTo, DiagramViewer v) {
		super(m, v);
		this.attachedTo = requireNonNull(attachedTo);
	}

	/** {@inheritDoc} */
	@Override
	public IMVCBundle getAttachedTo() {
		return attachedTo;
	}

	/** {@inheritDoc} */
	@Override
	public List<ILinkMVCBundle> getIncomingLinks() {
		return incomingLinks;
	}

	/** {@inheritDoc} */
	@Override
	public List<ILinkMVCBundle> getOutgoingLinks() {
		return outgoingLinks;
	}
}
