/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramLayers;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.EDragGesture;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundlePart;

import javafx.geometry.Rectangle2D;
import javafx.scene.Node;

/**
 * Interface for visuals (encapsulating a {@link Node}), which are created by
 * {@link IVisualFactory} and usually represent a single model element.
 */
public interface IVisual extends IMVCBundlePart {
	/**
	 * Updates the visual's nodes possibly adding or removing nodes from the scene graph using the
	 * diagram layers.
	 */
	void updateNodes(DiagramLayers layers);

	/**
	 * Removes any nodes from the layers before the {@link IMVCBundle} is removed from the diagram,
	 * e.g., because the model element was deleted.
	 */
	void removeAllVisuals(DiagramLayers layers);

	/** Returns whether this visual is currently visible. */
	boolean enableVisual();

	/** Returns whether this visual is currently receiving interactions. */
	boolean enableInteraction();

	/**
	 * Returns the current bounds computed from model and feedback coordinates relative to the
	 * diagram origin.
	 */
	Rectangle2D getCurrentBounds();

	/**
	 * Returns the bounds of the visual in the diagram coordinate space derived from the current
	 * model state.
	 */
	Rectangle2D getModelBounds();

	/**
	 * Returns the point used to start or end the link creation line feedback using the given
	 * location as an indication.
	 */
	DiagramCoordinate getLinkAnchorage(DiagramCoordinate indication);

	/** Requests the focus on a specific node determined by this visual. */
	void requestFocus();

	/**
	 * Returns the {@link EDragGesture} for the given node and diagram location.
	 * 
	 * @param node
	 *            the node to be checked
	 * @param diagramLocation
	 *            the location on the diagram
	 * @return the drag gesture that can be initiated at this location
	 */
	EDragGesture getDragGesture(Node node, DiagramCoordinate diagramLocation);
}
