/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewer;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IDiagramAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.ILinkMVCBundle;

/**
 * Interface for factories which create {@link IVisual}s from model elements for the
 * {@link DiagramViewer}. The factory creates four types of visuals: diagram anchorage, content,
 * content anchorage, and link visuals.
 */
public interface IVisualFactory {
	/** Returns a visual node for the given content model element bundle. */
	IContentVisual createContentVisual(IContentMVCBundle modelBundle);

	/** Returns a visual node for the given diagram anchorage model element bundle. */
	IDiagramAnchorageVisual createDiagramAnchorageVisual(IDiagramAnchorageMVCBundle modelBundle);

	/**
	 * Returns a visual node for the given content anchorage model element bundle. Sub-classes may
	 * assume that {@code modelBundle.getAttachedTo()} points to the parent bundle.
	 */
	IContentAnchorageVisual createContentAnchorageVisual(IContentAnchorageMVCBundle modelBundle);

	/**
	 * Returns a visual node for the given link model element bundle. Sub-classes may assume
	 * that {@code modelBundle.getDiagramMVCBundle()} points to the parent bundle.
	 */
	ILinkVisual createLinkVisual(ILinkMVCBundle modelBundle);
}
