/*******************************************************************************
 * Copyright (c) 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Anna Haas (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual.rectangular;

import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import javafx.scene.shape.Line;
import javafx.util.Pair;

/** This class represents all rectangular lines. */
public class LineLinkGraph {
	/** Maps the LineSegment to its Lines. */
	private Map<LineSegment, List<Line>> segment2lines = new HashMap<>();
	/** Maps the Line to its LineSegment. */
	private Map<Line, LineSegment> line2segment = new HashMap<>();
	/** Maps the Line to every Line Pair that is interrupted by it. */
	private Map<Line, Set<Pair<Line, Line>>> line2interruptedLine = new HashMap<>();

	/** Adds a new LineSegment to the graph. */
	public void addSegment(LineSegment seg, List<Line> lines) {
		segment2lines.put(seg, lines);
		for(Line l : lines) {
			line2segment.put(l, seg);
		}
	}

	/** Removes the LineSegment from the graph. */
	public void removeSegment(LineSegment seg, List<Line> lines) {
		segment2lines.remove(seg);
		for(Line l : lines) {
			line2segment.remove(l);
		}
	}

	/** Adds a new interrupted line. */
	public void addInterruptedLine(Line line, Line interruptedLine1, Line interruptedLine2) {
		Set<Pair<Line, Line>> set = line2interruptedLine.get(line);
		if(set == null)
			set = new HashSet<>();
		set.add(new Pair<>(interruptedLine1, interruptedLine2));
		line2interruptedLine.put(line, set);
	}

	/** Adds new interrupted lines. */
	public void addInterruptedLines(Map<Line, Pair<Line, Line>> lines) {
		for(Line line : lines.keySet()) {
			Pair<Line, Line> pair = lines.get(line);
			addInterruptedLine(line, pair.getKey(), pair.getValue());
		}
	}

	/** Returns line2segment. */
	public Map<Line, LineSegment> getLine2segment() {
		return line2segment;
	}
}
