/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.style;

import javafx.scene.canvas.GraphicsContext;
import javafx.scene.paint.Color;

/** Represents a style to be used in for filling areas. */
public final class FillStyle extends ColorStyleBase {
	/** Alpha transparency value (default is opaque 1.0). */
	private final double alpha;

	/** Constructor */
	public FillStyle(Color rgbColor) {
		this(rgbColor, 1);
	}

	/** Constructor */
	public FillStyle(Color c, double alpha) {
		super(new Color(c.getRed(), c.getBlue(), c.getGreen(), alpha));
		this.alpha = alpha;
	}

	/** Returns alpha value. */
	public double getAlpha() {
		return alpha;
	}

	/** Applies the style to the given graphics context. */
	public void applyStyle(GraphicsContext gc) {
		gc.setFill(getColor());
	}
}
