/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.editor.problembar;

import org.eclipse.core.resources.IMarker;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.graphics.Image;

import org.conqat.lib.commons.assertion.CCSMAssert;
import org.conqat.ide.commons.ui.marker.EMarkerSeverity;

/**
 * Label provider for markers.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: A574A2507096172C9DE42B5AD3755469
 */
class MarkerLabelProvider extends LabelProvider {

	/** {@inheritDoc} */
	@Override
	public String getText(Object element) {
		CCSMAssert
				.isTrue(element instanceof IMarker, "Only works for markers!");
		return ((IMarker) element).getAttribute(IMarker.MESSAGE,
				"Could not retrieve message.");
	}

	/**
	 * {@inheritDoc}.
	 */
	@Override
	public Image getImage(Object element) {
		if (element instanceof IMarker) {
			int eclipseSeverity = ((IMarker) element).getAttribute(
					IMarker.SEVERITY, IMarker.SEVERITY_INFO);
			EMarkerSeverity severity = EMarkerSeverity
					.getSeverity(eclipseSeverity);
			if (severity != null) {
				return severity.getIcon().getImage();
			}
		}
		return null;
	}
}