/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.ui;

import org.eclipse.jface.viewers.CellLabelProvider;
import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.viewers.TableViewerColumn;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerSorter;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;

/**
 * Utility methods for the {@link TableViewer}.
 * 
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: B9C218AFC25C412DCF24AB17B46758B4
 */
public class TableViewerUtils {

	/** Creates a column for a table viewer. */
	public static TableViewerColumn createColumn(TableViewer viewer,
			String text, int width, int style, CellLabelProvider labelProvider) {
		TableViewerColumn column = new TableViewerColumn(viewer, style);
		column.getColumn().setText(text);
		column.getColumn().setWidth(width);
		column.setLabelProvider(labelProvider);
		return column;
	}

	/**
	 * Creates a column for a table viewer that can be sorted by clicking on the
	 * caption.
	 */
	public static TableViewerColumn createSortableColumn(
			final TableViewer viewer, String text, int width, int style,
			CellLabelProvider labelProvider, final ViewerSorter sorter) {
		TableViewerColumn column = createColumn(viewer, text, width, style,
				labelProvider);

		column.getColumn().addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				if (viewer.getSorter() == sorter) {
					// use inverting sorter
					viewer.setSorter(new ViewerSorter() {
						@Override
						public int compare(Viewer viewer, Object e1, Object e2) {
							return sorter.compare(viewer, e2, e1);
						}
					});
				} else {
					viewer.setSorter(sorter);
				}
			}
		});

		return column;
	}

	/**
	 * Creates a column that is sortable and uses string comparison on the label
	 * created by the provider for comparison.
	 */
	public static TableViewerColumn createDefaultSortableColumn(
			final TableViewer viewer, String text, int width, int style,
			final ColumnLabelProvider labelProvider) {
		return createSortableColumn(viewer, text, width, style, labelProvider,
				new ViewerSorter() {
					@Override
					public int compare(Viewer viewer, Object e1, Object e2) {
						String text1 = labelProvider.getText(e1);
						String text2 = labelProvider.getText(e2);
						return text1.compareTo(text2);
					}
				});
	}
}